#
# spec file for package python-odorik
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-odorik
Version:        0.5
Release:        7.3
Summary:        Python module for Odorik API
License:        GPL-3.0-or-later
URL:            https://cihar.com/software/odorik/
Source:         https://files.pythonhosted.org/packages/source/o/odorik/odorik-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE assertEquals.patch mcepl@suse.com
# 3.12 finally removed assertEquals method
# Patch from gh#nijel/odorik#d90f3a6cd76972
Patch0:         assertEquals.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module httpretty}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pyxdg}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
Requires:       python-xdg
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Python module to work with Odorik API.

%prep
%autosetup -p1 -n odorik-%{version}

%build
%pyproject_wheel
%make_build -C docs man

%install
%pyproject_install
install -d %{buildroot}%{_mandir}/man1
install -m 644 docs/_build/man/odorik.1 %{buildroot}%{_mandir}/man1
%python_clone -a %{buildroot}%{_bindir}/odorik
%python_clone -a %{buildroot}%{_mandir}/man1/odorik.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest odorik

%post
%python_install_alternative odorik odorik.1

%postun
%python_uninstall_alternative odorik

%files %{python_files}
%license LICENSE
%doc NEWS.rst README.rst
%python_alternative %{_mandir}/man1/odorik.1%{ext_man}
%python_alternative %{_bindir}/odorik
%{python_sitelib}/odorik
%{python_sitelib}/odorik-%{version}*-info

%changelog
* Fri Mar 15 2024 Matej Cepl <mcepl@cepl.eu>
- Add assertEquals.patch replacing assertEquals with assertEqual
  (incompatible with Python 3.12).
* Tue Oct 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Aug 29 2018 tchvatal@suse.com
- Fix build on 42.3 by calling pytest properly and adding dependency
  on ssl module from python2 main package
* Tue May 22 2018 mcepl@suse.com
- clean SPEC file
- binaries and manpages are only in python3- package
- tests are run for both versions of Python
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Mon Jul 13 2015 mcihar@suse.cz
- Update to 0.5:
  * Documentation translated to Czech language.
  * More detailed summaries for calls and messages.
  * Added options for filtering calls by status and direction.
* Thu May 21 2015 mcihar@suse.cz
- Update to 0.4:
  * Adjustable date periods for commands.
  * Add support for listing calls.
  * Add support for listing SMS.
  * Add support for using names for phone numbers and lines.
  * Add summary command to print short overview.
* Mon May 18 2015 mcihar@suse.cz
- Update to 0.3:
  * Added support for listing lines information.
  * Added support for listing data usage for all lines on current account.
  * Documentation improvements.
  * Added html output to the program.
  * Added support for json and csv output.
  * Improved command line support for API calls.
  * Command line parameters can now override config file.
  * Added support for initiating callback.
- Update home page
* Fri May 15 2015 mcihar@suse.cz
- Initial packaging.
